@@ -874,15 +874,15 @@ color_changed_cb (GtkColorButton    *button,
                   CcAppearancePanel *panel)
 {
   CcAppearancePanelPrivate *priv = panel->priv;
-  GdkRGBA color;
+  GdkColor color;
   gchar *value;
   gboolean is_pcolor = FALSE;
 
-  gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (button), &color);
+  gtk_color_button_get_color (button, &color);
   if (WID ("style-pcolor") == GTK_WIDGET (button))
     is_pcolor = TRUE;
 
-  value = gdk_rgba_to_string (&color);
+  value = gdk_color_to_string (&color);
 
   if (priv->current_background)
     {
@@ -1857,7 +1857,7 @@ cc_appearance_panel_init (CcAppearancePanel *self)
   priv = self->priv = APPEARANCE_PANEL_PRIVATE (self);
 
   priv->builder = gtk_builder_new ();
-
+  gtk_builder_set_translation_domain (priv->builder, GETTEXT_PACKAGE);
   gtk_builder_add_objects_from_file (priv->builder,
                                        PKGDATADIR"/appearance.ui",
                                        objects_unity, &err);
